@@ -17,6 +17,7 @@
 """cubicweb-wsme tests
 """
 
+import base64
 import json
 import urllib
 
@@ -24,6 +25,7 @@ import wsme
 
 from cubicweb.devtools.testlib import CubicWebTC
 from cubicweb.devtools.httptest import CubicWebServerTC
+import cubicweb
 
 from cubes.wsme.types import Base, wsattr
 
@@ -400,6 +402,56 @@ class WSMECRUDTest(CubicWebServerTC):
 
             self.assertEqual(1, len(u.in_group))
 
+    def test_get_binary(self):
+        with self.admin_access.repo_cnx() as cnx:
+            f = cnx.create_entity(
+                'File', data=cubicweb.Binary('test'),
+                data_name=u'filename',
+                data_format=u'text/plain')
+            cnx.commit()
+            eid = f.eid
+
+        self.web_login()
+
+        res = self.web_request(
+            'file/{}'.format(eid),
+            headers={"Accept": "application/json"})
+
+        data = json.loads(res.body)
+        self.assertNotIn('faultcode', data)
+        self.assertEqual(200, res.status)
+
+        self.assertEqual(data['data'], base64.encodestring('test'))
+
+    def test_set_binary(self):
+        with self.admin_access.repo_cnx() as cnx:
+            f = cnx.create_entity(
+                'File', data=cubicweb.Binary('test'),
+                data_name=u'filename',
+                data_format=u'text/plain')
+            cnx.commit()
+            eid = f.eid
+
+        self.web_login()
+
+        res = self.web_request(
+            'file/{}'.format(eid),
+            method='PUT',
+            body=json.dumps({"data": base64.encodestring('newcontent')}),
+            headers={
+                "Accept": "application/json",
+                "Content-Type": "application/json"})
+
+        data = json.loads(res.body)
+        self.assertNotIn('faultcode', data)
+        self.assertEqual(200, res.status)
+
+        self.assertEqual(data['data'], base64.encodestring('newcontent'))
+
+        with self.admin_access.repo_cnx() as cnx:
+            f = cnx.entity_from_eid(eid)
+            self.assertEqual(f.data.getvalue(), 'newcontent')
+
 
 class WSMEQueryTest(CubicWebServerTC):
     @classmethod
